@@ -56,6 +56,8 @@ class QuickbooksCore(SitesCore):
                     self.browser.click_element_when_visible('//button[@id="ius-sign-in-submit-btn"]')
                 else:
                     self.browser.click_element_when_visible('//button[@id="ius-identifier-first-submit-btn"]')
+
+                    self.wait_element('//input[@data-testid="currentPasswordInput"]', 30, False)
                     if self.does_element_displayed('//input[@data-testid="currentPasswordInput"]'):
                         self.browser.input_text('//input[@data-testid="currentPasswordInput"]', self.password)
                         self.browser.click_element_when_visible(
@@ -123,6 +125,10 @@ class QuickbooksCore(SitesCore):
             self.browser.capture_page_screenshot(
                 os.path.join(self.output_folder, f'Element_not_available_{now.strftime("%H_%M_%S")}.png')
             )
+            html_file: str = os.path.join(self.output_folder, f'Element_not_available_{now.strftime("%H_%M_%S")}.html')
+            with open(html_file, "w", encoding="utf-8") as f:
+                f.write(self.browser.get_source())
+
         return is_success
 
     def __close_specific_windows(self, xpath: str) -> None:
